@@ -1,5 +1,7 @@
 #pragma once
 
+#include <cpp11/doubles.hpp>
+
 #include "vroom_dttm.h"
 
 using namespace vroom;
@@ -7,9 +9,9 @@ using namespace vroom;
 double parse_date(
     const string& str, DateTimeParser& parser, const std::string& format);
 
-Rcpp::NumericVector read_date(vroom_vec_info* info);
+cpp11::doubles read_date(vroom_vec_info* info);
 
-#if R_VERSION >= R_Version(3, 5, 0)
+#ifdef HAS_ALTREP
 /* no support for altrep before 3.5 */
 
 class vroom_date : public vroom_dttm {
@@ -27,9 +29,9 @@ public:
     SEXP out = PROTECT(R_MakeExternalPtr(dttm_info, R_NilValue, R_NilValue));
     R_RegisterCFinalizerEx(out, vroom_dttm::Finalize, FALSE);
 
-    Rcpp::RObject res = R_new_altrep(class_t, out, R_NilValue);
+    cpp11::sexp res = R_new_altrep(class_t, out, R_NilValue);
 
-    res.attr("class") = Rcpp::CharacterVector::create("Date");
+    res.attr("class") = {"Date"};
 
     UNPROTECT(1);
 
@@ -41,10 +43,10 @@ public:
   // What gets printed when .Internal(inspect()) is used
   static Rboolean Inspect(
       SEXP x,
-      int pre,
-      int deep,
-      int pvec,
-      void (*inspect_subtree)(SEXP, int, int, int)) {
+      int,
+      int,
+      int,
+      void (*)(SEXP, int, int, int)) {
     Rprintf(
         "vroom_date (len=%d, materialized=%s)\n",
         Length(x),
@@ -84,7 +86,7 @@ public:
     return out;
   }
 
-  static void* Dataptr(SEXP vec, Rboolean writeable) {
+  static void* Dataptr(SEXP vec, Rboolean) {
     return STDVEC_DATAPTR(Materialize(vec));
   }
 
@@ -107,6 +109,5 @@ public:
 };
 #endif
 
-// Called the package is loaded (needs Rcpp 0.12.18.3)
-// [[Rcpp::init]]
-void init_vroom_date(DllInfo* dll);
+// Called the package is loaded
+[[cpp11::init]] void init_vroom_date(DllInfo* dll);
