@@ -14,15 +14,15 @@ double parse_time(
   return NA_REAL;
 }
 
-Rcpp::NumericVector read_time(vroom_vec_info* info) {
+cpp11::doubles read_time(vroom_vec_info* info) {
   R_xlen_t n = info->column->size();
 
-  Rcpp::NumericVector out(n);
+  cpp11::writable::doubles out(n);
 
   parallel_for(
       n,
-      [&](size_t start, size_t end, size_t id) {
-        auto i = start;
+      [&](size_t start, size_t end, size_t) {
+        R_xlen_t i = start;
         DateTimeParser parser(info->locale.get());
         auto col = info->column->slice(start, end);
         for (const auto& str : *col) {
@@ -32,7 +32,7 @@ Rcpp::NumericVector read_time(vroom_vec_info* info) {
       info->num_threads,
       true);
 
-  out.attr("class") = Rcpp::CharacterVector::create("hms", "difftime");
+  out.attr("class") = {"hms", "difftime"};
   out.attr("units") = "secs";
 
   return out;
