@@ -1,5 +1,7 @@
 #pragma once
 
+#include <cpp11/doubles.hpp>
+
 #include "vroom.h"
 #include "vroom_dttm.h"
 
@@ -7,7 +9,7 @@ using namespace vroom;
 
 double parse_time(
     const string& str, DateTimeParser& parser, const std::string& format);
-Rcpp::NumericVector read_time(vroom_vec_info* info);
+cpp11::doubles read_time(vroom_vec_info* info);
 
 #ifdef HAS_ALTREP
 
@@ -26,9 +28,9 @@ public:
     SEXP out = PROTECT(R_MakeExternalPtr(dttm_info, R_NilValue, R_NilValue));
     R_RegisterCFinalizerEx(out, vroom_dttm::Finalize, FALSE);
 
-    Rcpp::RObject res = R_new_altrep(class_t, out, R_NilValue);
+    cpp11::sexp res = R_new_altrep(class_t, out, R_NilValue);
 
-    res.attr("class") = Rcpp::CharacterVector::create("hms", "difftime");
+    res.attr("class") = {"hms", "difftime"};
     res.attr("units") = "secs";
 
     UNPROTECT(1);
@@ -39,12 +41,8 @@ public:
   }
 
   // What gets printed when .Internal(inspect()) is used
-  static Rboolean Inspect(
-      SEXP x,
-      int pre,
-      int deep,
-      int pvec,
-      void (*inspect_subtree)(SEXP, int, int, int)) {
+  static Rboolean
+  Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
         "vroom_time (len=%d, materialized=%s)\n",
         Length(x),
@@ -84,7 +82,7 @@ public:
     return out;
   }
 
-  static void* Dataptr(SEXP vec, Rboolean writeable) {
+  static void* Dataptr(SEXP vec, Rboolean) {
     return STDVEC_DATAPTR(Materialize(vec));
   }
 
@@ -107,6 +105,5 @@ public:
 };
 #endif
 
-// Called the package is loaded (needs Rcpp 0.12.18.3)
-// [[Rcpp::init]]
-void init_vroom_time(DllInfo* dll);
+// Called the package is loaded
+[[cpp11::init]] void init_vroom_time(DllInfo* dll);
