@@ -1,8 +1,8 @@
-test_vroom <- function(content, delim = "\n", ..., equals) {
+test_vroom <- function(content, delim = "\n", col_types = list(), ..., equals) {
   # with altrep
   withr::with_envvar(c("VROOM_USE_ALTREP_CHR" = "true", "VROOM_USE_ALTREP_NUMERICS" = "true"), {
     expect_equal(
-      vroom(content, delim = delim, ...),
+      vroom(content, delim = delim, col_types = col_types, ...),
       equals
     )
   })
@@ -10,7 +10,7 @@ test_vroom <- function(content, delim = "\n", ..., equals) {
   # without altrep
   withr::with_envvar(c("VROOM_USE_ALTREP_CHR" = "false", "VROOM_USE_ALTREP_NUMERICS" = "false"), {
     expect_equal(
-      vroom(content, delim = delim, ...),
+      vroom(content, delim = delim, col_types = col_types, ...),
       equals
     )
   })
@@ -28,7 +28,7 @@ test_vroom <- function(content, delim = "\n", ..., equals) {
   }
   on.exit(close(con), add = TRUE)
 
-  res <- vroom(con, delim = delim, ...)
+  res <- vroom(con, delim = delim, col_types = col_types, ...)
 
   expect_equal(res, equals)
   for (i in seq_along(res)) {
